from pathlib import Path


__name__ = 'CQUPT Piper'
__generation__ = '0.0.12'
__version__ = f'v{__generation__}-light'
__author__ = 'XJJ'
__description__ = f'{__name__} {__version__} @{__author__}'

PIPER_HOME = f'{Path.home()}/.piper'
